<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation>Torna a arrencar Fluxbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Restart IceWM</source>
        <translation>Reinicia IceWM</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart JWM</source>
        <translation>Reinicia JWM</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Lock Screen</source>
        <translation>Bloca la pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Log Out</source>
        <translation>Finalitza la Sessió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="42"/>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Finestra emergent amb opcions de sortida per MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation>Mostra els botons en una finestra vertical</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Mostra els botons en una finestra horitzontal</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation>Duració del temps d&apos;espera en segons</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>useu -v, --vertical per mostrar els botons verticalment
useu -h, --horizontal per mostrar els botons horitzontalment.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Ús: exit-options [opcions]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 Opció per mostrar els botons horitzontalment</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 Opció per mostrar els botons verticalment</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 Duració del temps d&apos;espera en segons
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Es recordarà l&apos;opció d&apos;orientació usada i s&apos;usarà la pròxima vegada que arrenqueu l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternativament, poseu l&apos;opció &apos;layout=horizontal&apos; o &apos;layout=vertical&apos; a ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>Per definir el temps d&apos;espera al fitxer exit-options.conf useu &quot;timeout=X&quot; on X és el temps d&apos;espera en segons.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation>També podeu usar &quot;timeout=off&quot; per desactivar el temps d&apos;espera.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Podeu definir icones a mida afegint IconName=/path/iconame.ext al fitxer de configuració exit-options.conf. Els noms de les icones que remapeu: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Es poden definir altres opcions al fitxer de configuració exit-options.conf: %1</translation>
    </message>
</context>
</TS>